package javax.swing.plaf.metal;

import java.awt.event.WindowAdapter;
import java.beans.PropertyChangeEvent;
import java.awt.Container;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.border.EmptyBorder;
import java.util.List;
import sun.awt.SunToolkit;
import java.awt.FontMetrics;
import java.awt.Rectangle;
import sun.swing.SwingUtilities2;
import java.awt.Graphics;
import java.awt.Dialog;
import javax.swing.plaf.UIResource;
import java.awt.LayoutManager;
import javax.swing.JMenuItem;
import javax.swing.JSeparator;
import java.awt.Toolkit;
import javax.swing.JMenu;
import java.awt.event.WindowEvent;
import java.awt.Frame;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import java.awt.Color;
import javax.swing.JRootPane;
import java.awt.Window;
import java.awt.event.WindowListener;
import java.awt.Image;
import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.Action;
import javax.swing.JMenuBar;
import java.beans.PropertyChangeListener;
import javax.swing.border.Border;
import javax.swing.JComponent;

class MetalTitlePane extends JComponent
{
    private static final Border handyEmptyBorder;
    private static final int IMAGE_HEIGHT = 16;
    private static final int IMAGE_WIDTH = 16;
    private PropertyChangeListener propertyChangeListener;
    private JMenuBar menuBar;
    private Action closeAction;
    private Action iconifyAction;
    private Action restoreAction;
    private Action maximizeAction;
    private JButton toggleButton;
    private JButton iconifyButton;
    private JButton closeButton;
    private Icon maximizeIcon;
    private Icon minimizeIcon;
    private Image systemIcon;
    private WindowListener windowListener;
    private Window window;
    private JRootPane rootPane;
    private int buttonsWidth;
    private int state;
    private MetalRootPaneUI rootPaneUI;
    private Color inactiveBackground;
    private Color inactiveForeground;
    private Color inactiveShadow;
    private Color activeBumpsHighlight;
    private Color activeBumpsShadow;
    private Color activeBackground;
    private Color activeForeground;
    private Color activeShadow;
    private MetalBumps activeBumps;
    private MetalBumps inactiveBumps;
    
    public MetalTitlePane(JRootPane rootPane, MetalRootPaneUI rootPaneUI) {
        this.inactiveBackground = UIManager.getColor("inactiveCaption");
        this.inactiveForeground = UIManager.getColor("inactiveCaptionText");
        this.inactiveShadow = UIManager.getColor("inactiveCaptionBorder");
        this.activeBumpsHighlight = MetalLookAndFeel.getPrimaryControlHighlight();
        this.activeBumpsShadow = MetalLookAndFeel.getPrimaryControlDarkShadow();
        this.activeBackground = null;
        this.activeForeground = null;
        this.activeShadow = null;
        this.activeBumps = new MetalBumps(0, 0, this.activeBumpsHighlight, this.activeBumpsShadow, MetalLookAndFeel.getPrimaryControl());
        this.inactiveBumps = new MetalBumps(0, 0, MetalLookAndFeel.getControlHighlight(), MetalLookAndFeel.getControlDarkShadow(), MetalLookAndFeel.getControl());
        this.rootPane = rootPane;
        this.rootPaneUI = rootPaneUI;
        this.state = -1;
        this.installSubcomponents();
        this.determineColors();
        this.installDefaults();
        this.setLayout(this.createLayout());
    }
    
    private void uninstall() {
        this.uninstallListeners();
        this.window = null;
        this.removeAll();
    }
    
    private void installListeners() {
        if (this.window != null) {
            this.windowListener = this.createWindowListener();
            this.window.addWindowListener(this.windowListener);
            this.propertyChangeListener = this.createWindowPropertyChangeListener();
            this.window.addPropertyChangeListener(this.propertyChangeListener);
        }
    }
    
    private void uninstallListeners() {
        if (this.window != null) {
            this.window.removeWindowListener(this.windowListener);
            this.window.removePropertyChangeListener(this.propertyChangeListener);
        }
    }
    
    private WindowListener createWindowListener() {
        return new MetalTitlePane.WindowHandler();
    }
    
    private PropertyChangeListener createWindowPropertyChangeListener() {
        return new MetalTitlePane.PropertyChangeHandler();
    }
    
    @Override
    public JRootPane getRootPane() {
        return this.rootPane;
    }
    
    private int getWindowDecorationStyle() {
        return this.getRootPane().getWindowDecorationStyle();
    }
    
    @Override
    public void addNotify() {
        super.addNotify();
        this.uninstallListeners();
        this.window = SwingUtilities.getWindowAncestor(this);
        if (this.window != null) {
            if ((this.window instanceof Frame)) {
                this.setState(((Frame)this.window).getExtendedState());
            }
            else {
                this.setState(0);
            }
            this.setActive(this.window.isActive());
            this.installListeners();
            this.updateSystemIcon();
        }
    }
    
    @Override
    public void removeNotify() {
        super.removeNotify();
        this.uninstallListeners();
        this.window = null;
    }
    
    private void installSubcomponents() {
        int windowDecorationStyle = this.getWindowDecorationStyle();
        if (windowDecorationStyle == 1) {
            this.createActions();
            this.add(this.menuBar = this.createMenuBar());
            this.createButtons();
            this.add(this.iconifyButton);
            this.add(this.toggleButton);
            this.add(this.closeButton);
        }
        else if (windowDecorationStyle == 2 || windowDecorationStyle == 3 || windowDecorationStyle == 4 || windowDecorationStyle == 5 || windowDecorationStyle == 6 || windowDecorationStyle == 7 || windowDecorationStyle == 8) {
            this.createActions();
            this.createButtons();
            this.add(this.closeButton);
        }
    }
    
    private void determineColors() {
        switch (this.getWindowDecorationStyle()) {
            case 1: {
                this.activeBackground = UIManager.getColor("activeCaption");
                this.activeForeground = UIManager.getColor("activeCaptionText");
                this.activeShadow = UIManager.getColor("activeCaptionBorder");
                break;
            }
            case 4: {
                this.activeBackground = UIManager.getColor("OptionPane.errorDialog.titlePane.background");
                this.activeForeground = UIManager.getColor("OptionPane.errorDialog.titlePane.foreground");
                this.activeShadow = UIManager.getColor("OptionPane.errorDialog.titlePane.shadow");
                break;
            }
            case 5:
            case 6:
            case 7: {
                this.activeBackground = UIManager.getColor("OptionPane.questionDialog.titlePane.background");
                this.activeForeground = UIManager.getColor("OptionPane.questionDialog.titlePane.foreground");
                this.activeShadow = UIManager.getColor("OptionPane.questionDialog.titlePane.shadow");
                break;
            }
            case 8: {
                this.activeBackground = UIManager.getColor("OptionPane.warningDialog.titlePane.background");
                this.activeForeground = UIManager.getColor("OptionPane.warningDialog.titlePane.foreground");
                this.activeShadow = UIManager.getColor("OptionPane.warningDialog.titlePane.shadow");
                break;
            }
            default: {
                this.activeBackground = UIManager.getColor("activeCaption");
                this.activeForeground = UIManager.getColor("activeCaptionText");
                this.activeShadow = UIManager.getColor("activeCaptionBorder");
                break;
            }
        }
        this.activeBumps.setBumpColors(this.activeBumpsHighlight, this.activeBumpsShadow, this.activeBackground);
    }
    
    private void installDefaults() {
        this.setFont(UIManager.getFont("InternalFrame.titleFont", this.getLocale()));
    }
    
    private void uninstallDefaults() {
    }
    
    protected JMenuBar createMenuBar() {
        (this.menuBar = new MetalTitlePane.SystemMenuBar()).setFocusable(false);
        this.menuBar.setBorderPainted(true);
        this.menuBar.add(this.createMenu());
        return this.menuBar;
    }
    
    private void close() {
        Window window = this.getWindow();
        if (window != null) {
            window.dispatchEvent(new WindowEvent(window, 201));
        }
    }
    
    private void iconify() {
        Frame frame = this.getFrame();
        if (frame != null) {
            frame.setExtendedState(this.state | 0x1);
        }
    }
    
    private void maximize() {
        Frame frame = this.getFrame();
        if (frame != null) {
            frame.setExtendedState(this.state | 0x6);
        }
    }
    
    private void restore() {
        Frame frame = this.getFrame();
        if (frame == null) {
            return;
        }
        if ((this.state & 0x1) != 0x0) {
            frame.setExtendedState(this.state & 0xFFFFFFFE);
        }
        else {
            frame.setExtendedState(this.state & 0xFFFFFFF9);
        }
        return;
    }
    
    private void createActions() {
        this.closeAction = new MetalTitlePane.CloseAction();
        if (this.getWindowDecorationStyle() == 1) {
            this.iconifyAction = new MetalTitlePane.IconifyAction();
            this.restoreAction = new MetalTitlePane.RestoreAction();
            this.maximizeAction = new MetalTitlePane.MaximizeAction();
        }
    }
    
    private JMenu createMenu() {
        JMenu menu = new JMenu("");
        if (this.getWindowDecorationStyle() == 1) {
            this.addMenuItems(menu);
            return menu;
        }
        return menu;
    }
    
    private void addMenuItems(JMenu menu) {
        this.getRootPane().getLocale();
        JMenuItem add = menu.add(this.restoreAction);
        int int1 = MetalUtils.getInt("MetalTitlePane.restoreMnemonic", -1);
        if (int1 != -1) {
            add.setMnemonic(int1);
        }
        JMenuItem add2 = menu.add(this.iconifyAction);
        int int2 = MetalUtils.getInt("MetalTitlePane.iconifyMnemonic", -1);
        if (int2 != -1) {
            add2.setMnemonic(int2);
        }
        if (Toolkit.getDefaultToolkit().isFrameStateSupported(6)) {
            JMenuItem add3 = menu.add(this.maximizeAction);
            int int3 = MetalUtils.getInt("MetalTitlePane.maximizeMnemonic", -1);
            if (int3 != -1) {
                add3.setMnemonic(int3);
            }
        }
        menu.add(new JSeparator());
        JMenuItem add4 = menu.add(this.closeAction);
        int int4 = MetalUtils.getInt("MetalTitlePane.closeMnemonic", -1);
        if (int4 != -1) {
            add4.setMnemonic(int4);
        }
    }
    
    private JButton createTitleButton() {
        JButton button = new JButton();
        button.setFocusPainted(false);
        button.setFocusable(false);
        button.setOpaque(true);
        return button;
    }
    
    private void createButtons() {
        (this.closeButton = this.createTitleButton()).setAction(this.closeAction);
        this.closeButton.setText(null);
        this.closeButton.putClientProperty("paintActive", Boolean.TRUE);
        this.closeButton.setBorder(MetalTitlePane.handyEmptyBorder);
        this.closeButton.putClientProperty("AccessibleName", "Close");
        this.closeButton.setIcon(UIManager.getIcon("InternalFrame.closeIcon"));
        if (this.getWindowDecorationStyle() == 1) {
            this.maximizeIcon = UIManager.getIcon("InternalFrame.maximizeIcon");
            this.minimizeIcon = UIManager.getIcon("InternalFrame.minimizeIcon");
            (this.iconifyButton = this.createTitleButton()).setAction(this.iconifyAction);
            this.iconifyButton.setText(null);
            this.iconifyButton.putClientProperty("paintActive", Boolean.TRUE);
            this.iconifyButton.setBorder(MetalTitlePane.handyEmptyBorder);
            this.iconifyButton.putClientProperty("AccessibleName", "Iconify");
            this.iconifyButton.setIcon(UIManager.getIcon("InternalFrame.iconifyIcon"));
            (this.toggleButton = this.createTitleButton()).setAction(this.restoreAction);
            this.toggleButton.putClientProperty("paintActive", Boolean.TRUE);
            this.toggleButton.setBorder(MetalTitlePane.handyEmptyBorder);
            this.toggleButton.putClientProperty("AccessibleName", "Maximize");
            this.toggleButton.setIcon(this.maximizeIcon);
        }
    }
    
    private LayoutManager createLayout() {
        return new MetalTitlePane.TitlePaneLayout();
    }
    
    private void setActive(boolean b) {
        Boolean value = b ? Boolean.TRUE : Boolean.FALSE;
        this.closeButton.putClientProperty("paintActive", value);
        if (this.getWindowDecorationStyle() == 1) {
            this.iconifyButton.putClientProperty("paintActive", value);
            this.toggleButton.putClientProperty("paintActive", value);
        }
        this.getRootPane().repaint();
    }
    
    private void setState(int n) {
        this.setState(n, false);
    }
    
    private void setState(int state, boolean b) {
        if (this.getWindow() != null && this.getWindowDecorationStyle() == 1) {
            if (this.state == state && !b) {
                return;
            }
            Frame frame = this.getFrame();
            if (frame != null) {
                JRootPane rootPane = this.getRootPane();
                if ((state & 0x6) != 0x0 && (rootPane.getBorder() == null || rootPane.getBorder() instanceof UIResource) && frame.isShowing()) {
                    rootPane.setBorder(null);
                }
                else if ((state & 0x6) == 0x0) {
                    this.rootPaneUI.installBorder(rootPane);
                }
                if (frame.isResizable()) {
                    if ((state & 0x6) != 0x0) {
                        this.updateToggleButton(this.restoreAction, this.minimizeIcon);
                        this.maximizeAction.setEnabled(false);
                        this.restoreAction.setEnabled(true);
                    }
                    else {
                        this.updateToggleButton(this.maximizeAction, this.maximizeIcon);
                        this.maximizeAction.setEnabled(true);
                        this.restoreAction.setEnabled(false);
                    }
                    if (this.toggleButton.getParent() == null || this.iconifyButton.getParent() == null) {
                        this.add(this.toggleButton);
                        this.add(this.iconifyButton);
                        this.revalidate();
                        this.repaint();
                    }
                    this.toggleButton.setText(null);
                }
                else {
                    this.maximizeAction.setEnabled(false);
                    this.restoreAction.setEnabled(false);
                    if (this.toggleButton.getParent() != null) {
                        this.remove(this.toggleButton);
                        this.revalidate();
                        this.repaint();
                    }
                }
            }
            else {
                this.maximizeAction.setEnabled(false);
                this.restoreAction.setEnabled(false);
                this.iconifyAction.setEnabled(false);
                this.remove(this.toggleButton);
                this.remove(this.iconifyButton);
                this.revalidate();
                this.repaint();
            }
            this.closeAction.setEnabled(true);
            this.state = state;
        }
    }
    
    private void updateToggleButton(Action action, Icon icon) {
        this.toggleButton.setAction(action);
        this.toggleButton.setIcon(icon);
        this.toggleButton.setText(null);
    }
    
    private Frame getFrame() {
        Window window = this.getWindow();
        if ((window instanceof Frame)) {
            return (Frame)window;
        }
        return null;
    }
    
    private Window getWindow() {
        return this.window;
    }
    
    private String getTitle() {
        Window window = this.getWindow();
        if ((window instanceof Frame)) {
            return ((Frame)window).getTitle();
        }
        if ((window instanceof Dialog)) {
            return ((Dialog)window).getTitle();
        }
        return null;
    }
    
    public void paintComponent(Graphics graphics) {
        if (this.getFrame() != null) {
            this.setState(this.getFrame().getExtendedState());
        }
        JRootPane rootPane = this.getRootPane();
        Window window = this.getWindow();
        int n = (window == null) ? rootPane.getComponentOrientation().isLeftToRight() : window.getComponentOrientation().isLeftToRight();
        int n2 = window == null || window.isActive();
        int width = this.getWidth();
        int height = this.getHeight();
        Color color;
        Color color2;
        Color color3;
        MetalBumps metalBumps;
        if (!(n2 == 0)) {
            color = this.activeBackground;
            color2 = this.activeForeground;
            color3 = this.activeShadow;
            metalBumps = this.activeBumps;
        }
        else {
            color = this.inactiveBackground;
            color2 = this.inactiveForeground;
            color3 = this.inactiveShadow;
            metalBumps = this.inactiveBumps;
        }
        graphics.setColor(color);
        graphics.fillRect(0, 0, width, height);
        graphics.setColor(color3);
        graphics.drawLine(0, height - 1, width, height - 1);
        graphics.drawLine(0, 0, 0, 0);
        graphics.drawLine(width - 1, 0, width - 1, 0);
        int x = n ? 5 : (width - 5);
        if (this.getWindowDecorationStyle() == 1) {
            x += (n ? 21 : -21);
        }
        String title = this.getTitle();
        if (title != null) {
            FontMetrics fontMetrics = SwingUtilities2.getFontMetrics(rootPane, graphics);
            graphics.setColor(color2);
            int y = (height - fontMetrics.getHeight()) / 2 + fontMetrics.getAscent();
            Rectangle bounds = new Rectangle(0, 0, 0, 0);
            if (this.iconifyButton != null && this.iconifyButton.getParent() != null) {
                bounds = this.iconifyButton.getBounds();
            }
            String text;
            if (!(n == 0)) {
                if (bounds.x == 0) {
                    bounds.x = window.getWidth() - window.getInsets().right - 2;
                }
                text = SwingUtilities2.clipStringIfNecessary(rootPane, fontMetrics, title, bounds.x - x - 4);
            }
            else {
                text = SwingUtilities2.clipStringIfNecessary(rootPane, fontMetrics, title, x - bounds.x - bounds.width - 4);
                x -= SwingUtilities2.stringWidth(rootPane, fontMetrics, text);
            }
            int stringWidth = SwingUtilities2.stringWidth(rootPane, fontMetrics, text);
            SwingUtilities2.drawString(rootPane, graphics, text, x, y);
            x += (n ? (stringWidth + 5) : -5);
        }
        int n3;
        if (!(n == 0)) {
            n3 = width - this.buttonsWidth - x - 5;
        }
        else {
            n3 = x - this.buttonsWidth - 5;
            x = this.buttonsWidth + 5;
        }
        int n4 = 3;
        metalBumps.setBumpArea(n3, this.getHeight() - 2 * n4);
        metalBumps.paintIcon(this, graphics, x, n4);
    }
    
    private void updateSystemIcon() {
        Window window = this.getWindow();
        if (window == null) {
            this.systemIcon = null;
            return;
        }
        List<Image> iconImages = window.getIconImages();
        assert iconImages != null;
        if (iconImages.size() == 0) {
            this.systemIcon = null;
        }
        else if (iconImages.size() == 1) {
            this.systemIcon = (Image)iconImages.get(0);
        }
        else {
            this.systemIcon = SunToolkit.getScaledIconImage(iconImages, 16, 16);
        }
        return;
    }
    
    static void access$400(MetalTitlePane metalTitlePane) {
        metalTitlePane.close();
    }
    
    static void access$500(MetalTitlePane metalTitlePane) {
        metalTitlePane.iconify();
    }
    
    static void access$600(MetalTitlePane metalTitlePane) {
        metalTitlePane.restore();
    }
    
    static void access$700(MetalTitlePane metalTitlePane) {
        metalTitlePane.maximize();
    }
    
    static int access$1000(MetalTitlePane metalTitlePane) {
        return metalTitlePane.getWindowDecorationStyle();
    }
    
    static Frame access$1700(MetalTitlePane metalTitlePane) {
        return metalTitlePane.getFrame();
    }
    
    static void access$1800(MetalTitlePane metalTitlePane, int n, boolean b) {
        metalTitlePane.setState(n, b);
    }
    
    static void access$1900(MetalTitlePane metalTitlePane) {
        metalTitlePane.updateSystemIcon();
    }
    
    static void access$2000(MetalTitlePane metalTitlePane, boolean active) {
        metalTitlePane.setActive(active);
    }
    
    static {
        handyEmptyBorder = new EmptyBorder(0, 0, 0, 0);
    }
    
    private class CloseAction extends AbstractAction
    {
        public CloseAction() {
            super(UIManager.getString("MetalTitlePane.closeTitle", MetalTitlePane.this.getLocale()));
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            MetalTitlePane.access$400(MetalTitlePane.this);
        }
    }
    
    private class IconifyAction extends AbstractAction
    {
        public IconifyAction() {
            super(UIManager.getString("MetalTitlePane.iconifyTitle", MetalTitlePane.this.getLocale()));
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            MetalTitlePane.access$500(MetalTitlePane.this);
        }
    }
    
    private class RestoreAction extends AbstractAction
    {
        public RestoreAction() {
            super(UIManager.getString("MetalTitlePane.restoreTitle", MetalTitlePane.this.getLocale()));
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            MetalTitlePane.access$600(MetalTitlePane.this);
        }
    }
    
    private class MaximizeAction extends AbstractAction
    {
        public MaximizeAction() {
            super(UIManager.getString("MetalTitlePane.maximizeTitle", MetalTitlePane.this.getLocale()));
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            MetalTitlePane.access$700(MetalTitlePane.this);
        }
    }
    
    private class SystemMenuBar extends JMenuBar
    {
        @Override
        public void paint(Graphics graphics) {
            if (this.isOpaque()) {
                graphics.setColor(this.getBackground());
                graphics.fillRect(0, 0, this.getWidth(), this.getHeight());
            }
            if (MetalTitlePane.this.systemIcon != null) {
                graphics.drawImage(MetalTitlePane.this.systemIcon, 0, 0, 16, 16, null);
            }
            else {
                Icon icon = UIManager.getIcon("InternalFrame.icon");
                if (icon != null) {
                    icon.paintIcon(this, graphics, 0, 0);
                }
            }
        }
        
        @Override
        public Dimension getMinimumSize() {
            return this.getPreferredSize();
        }
        
        @Override
        public Dimension getPreferredSize() {
            Dimension preferredSize = super.getPreferredSize();
            return new Dimension(Math.max(16, preferredSize.width), Math.max(preferredSize.height, 16));
        }
    }
    
    private class TitlePaneLayout implements LayoutManager
    {
        @Override
        public void addLayoutComponent(String s, Component component) {
        }
        
        @Override
        public void removeLayoutComponent(Component component) {
        }
        
        @Override
        public Dimension preferredLayoutSize(Container container) {
            int computeHeight = this.computeHeight();
            return new Dimension(computeHeight, computeHeight);
        }
        
        @Override
        public Dimension minimumLayoutSize(Container container) {
            return this.preferredLayoutSize(container);
        }
        
        private int computeHeight() {
            int height = MetalTitlePane.this.rootPane.getFontMetrics(MetalTitlePane.this.getFont()).getHeight();
            height += 7;
            int b = 0;
            if (MetalTitlePane.access$1000(MetalTitlePane.this) == 1) {
                b = 16;
            }
            return Math.max(height, b);
        }
        
        @Override
        public void layoutContainer(Container container) {
            int n = (MetalTitlePane.this.window == null) ? MetalTitlePane.this.getRootPane().getComponentOrientation().isLeftToRight() : MetalTitlePane.this.window.getComponentOrientation().isLeftToRight();
            int width = MetalTitlePane.this.getWidth();
            int n2 = 3;
            int iconHeight;
            int iconWidth;
            if (MetalTitlePane.this.closeButton != null && MetalTitlePane.this.closeButton.getIcon() != null) {
                iconHeight = MetalTitlePane.this.closeButton.getIcon().getIconHeight();
                iconWidth = MetalTitlePane.this.closeButton.getIcon().getIconWidth();
            }
            else {
                iconHeight = 16;
                iconWidth = 16;
            }
            int n3 = n ? width : false;
            int n4 = 5;
            int x = n ? n4 : (width - iconWidth - n4);
            if (MetalTitlePane.this.menuBar != null) {
                MetalTitlePane.this.menuBar.setBounds(x, n2, iconWidth, iconHeight);
            }
            int n5 = n ? width : 0;
            int n6 = 4;
            int x2 = n5 + (n ? (-n6 - iconWidth) : n6);
            if (MetalTitlePane.this.closeButton != null) {
                MetalTitlePane.this.closeButton.setBounds(x2, n2, iconWidth, iconHeight);
            }
            if (n == 0) {
                x2 += iconWidth;
            }
            if (MetalTitlePane.access$1000(MetalTitlePane.this) == 1) {
                if (Toolkit.getDefaultToolkit().isFrameStateSupported(6) && MetalTitlePane.this.toggleButton.getParent() != null) {
                    int n7 = 10;
                    x2 += (n ? (-n7 - iconWidth) : n7);
                    MetalTitlePane.this.toggleButton.setBounds(x2, n2, iconWidth, iconHeight);
                    if (n == 0) {
                        x2 += iconWidth;
                    }
                }
                if (MetalTitlePane.this.iconifyButton != null && MetalTitlePane.this.iconifyButton.getParent() != null) {
                    int n8 = 2;
                    x2 += (n ? (-n8 - iconWidth) : n8);
                    MetalTitlePane.this.iconifyButton.setBounds(x2, n2, iconWidth, iconHeight);
                    if (n == 0) {
                        x2 += iconWidth;
                    }
                }
            }
            MetalTitlePane.this.buttonsWidth = (n ? (width - x2) : x2);
        }
    }
    
    private class PropertyChangeHandler implements PropertyChangeListener
    {
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            String propertyName = propertyChangeEvent.getPropertyName();
            if ("resizable".equals(propertyName) || "state".equals(propertyName)) {
                Frame access$1700 = MetalTitlePane.access$1700(MetalTitlePane.this);
                if (access$1700 != null) {
                    MetalTitlePane.access$1800(MetalTitlePane.this, access$1700.getExtendedState(), true);
                }
                if ("resizable".equals(propertyName)) {
                    MetalTitlePane.this.getRootPane().repaint();
                }
            }
            else if ("title".equals(propertyName)) {
                MetalTitlePane.this.repaint();
            }
            else if ("componentOrientation" == propertyName) {
                MetalTitlePane.this.revalidate();
                MetalTitlePane.this.repaint();
            }
            else if ("iconImage" == propertyName) {
                MetalTitlePane.access$1900(MetalTitlePane.this);
                MetalTitlePane.this.revalidate();
                MetalTitlePane.this.repaint();
            }
        }
    }
    
    private class WindowHandler extends WindowAdapter
    {
        @Override
        public void windowActivated(WindowEvent windowEvent) {
            MetalTitlePane.access$2000(MetalTitlePane.this, true);
        }
        
        @Override
        public void windowDeactivated(WindowEvent windowEvent) {
            MetalTitlePane.access$2000(MetalTitlePane.this, false);
        }
    }
}
